# Changelog

All notable changes to VPN Monitor will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### 🚀 Features

- Publish to pypi ([#6](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/6)) by @henrykp in [#6](https://github.com/henrykp/vpn_status_monitor/pull/6)

## [0.5.0] - 2025-11-28

### 🚀 Features

- Fix build ([#5](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/5)) by @henrykp in [#5](https://github.com/henrykp/vpn_status_monitor/pull/5)

### 🐛 Bug Fixes

- Fix linter issues ([#3](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/3)) by @henrykp in [#3](https://github.com/henrykp/vpn_status_monitor/pull/3)

### 📚 Documentation

- Update CHANGELOG.md for v0.4.0 by @henrykp

### ⚙️ CI/CD

- **deps:** Bump the github-actions group with 7 updates ([#1](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/1)) by @dependabot[bot] in [#1](https://github.com/henrykp/vpn_status_monitor/pull/1)

## [0.2.0] - 2025-11-28

### 🚀 Features

- First commit by @henrykp

<!-- generated by git-cliff -->
